@@ -6,6 +6,7 @@ use base 'HTML::Tested';
 __PACKAGE__->make_tested_value('hello');
 __PACKAGE__->make_tested_value('v1');
 __PACKAGE__->make_tested_edit_box('file');
+__PACKAGE__->make_tested_hidden('hid', is_sealed => 1);
 
 package T::HTPage;
 use base 'Apache::SWIT::HTPage';
@@ -15,6 +16,7 @@ sub ht_root_class { return 'T::HTPage::Root'; }
 sub ht_swit_render {
 	my ($class, $r, $root) = @_;
 	$root->hello('world');
+	$root->hid($root->hid || 'secret');
 	return $root;
 }
 
