@@ -11,14 +11,14 @@ use base 'Apache::SWIT::HTPage';
 sub ht_root_class { return 'T::SessPage::Root'; }
 
 sub ht_swit_render {
-	my ($class, $r, $root, $session) = @_;
-	$root->persbox($session->get_persbox);
-	return ($r->server_root_relative('templates/sess_page.tt'), $root);
+	my ($class, $r, $root) = @_;
+	$root->persbox($r->pnotes('SWITSession')->get_persbox);
+	return $root;
 }
 
 sub ht_swit_update {
-	my ($class, $r, $root, $session) = @_;
-	$session->set_persbox($root->persbox);
+	my ($class, $r, $root) = @_;
+	$r->pnotes('SWITSession')->set_persbox($root->persbox);
 	return '/test/sess_page/r';
 }
 
